pub struct BindQuery {
pub resource: Option<String>,
}Expand description
The request for resource binding, which is the process by which a client can obtain a full JID and start exchanging on the XMPP network.
Fields
resource: Option<String>Requests this resource, the server may associate another one though.
If this is None, we request no particular resource, and a random one will be affected by the server.
Implementations